@@ -5,9 +5,6 @@
 #' @param model An object of class \code{lm}.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
-#' @section Deprecated Function:
-#' \code{ols_rsd_hist()} has been deprecated. Instead use \code{ols_plot_resid_hist()}.
-#'
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
 #' ols_plot_resid_hist(model)
@@ -23,8 +20,6 @@ ols_plot_resid_hist <- function(model, print_plot = TRUE) {
 
   check_model(model)
 
-  x  <- NULL
-  y  <- NULL
   k  <- histdata(model)
   h  <- hist(k$resid, plot = FALSE)
   l  <- histn(k$resid, h)
@@ -34,8 +29,9 @@ ols_plot_resid_hist <- function(model, print_plot = TRUE) {
   p <-
     ggplot(d, aes(x = x)) +
     geom_histogram(bins = 6, color = "black", fill = "#ADD8E6") +
-    geom_line(data = d2, aes(x = x, y = y), color = "#0000A0", size = 1.2) +
-    xlab("Residuals") + ggtitle("Residual Histogram")
+    geom_line(data = d2, aes(x = x, y = y), color = "#0000A0", linewidth = 1.2) +
+    xlab("Residuals") + 
+    ggtitle("Residual Histogram")
 
   if (print_plot) {
     print(p)
@@ -61,13 +57,4 @@ histn <- function(resid, h) {
   yfit1 <- yfit * diff(h$mids[1:2]) * length(resid)
   list(xfit = xfit, yfit = yfit1)
 
-}
-
-
-#' @export
-#' @rdname ols_plot_resid_hist
-#' @usage NULL
-#'
-ols_rsd_hist <- function(model) {
-  .Deprecated("ols_plot_resid_hist()")
-}
+}
\ No newline at end of file
