@@ -3,6 +3,7 @@
 #' Graph for identifying outliers.
 #'
 #' @param model An object of class \code{lm}.
+#' @param threshold Threshold for detecting outliers. Default is 3.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
 #' @details
@@ -20,12 +21,10 @@
 #' exceed \code{threshold}} for classifying an observation as an outlier
 #' \item{threshold}{\code{threshold} for classifying an observation as an outlier}
 #'
-#' @section Deprecated Function:
-#' \code{ols_srsd_plot()} has been deprecated. Instead use \code{ols_plot_resid_stud()}.
-#'
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
 #' ols_plot_resid_stud(model)
+#' ols_plot_resid_stud(model, threshold = 2)
 #'
 #' @importFrom ggplot2 scale_fill_manual annotate
 #'
@@ -33,53 +32,50 @@
 #'
 #' @export
 #'
-ols_plot_resid_stud <- function(model, print_plot = TRUE) {
+ols_plot_resid_stud <- function(model, threshold = NULL, print_plot = TRUE) {
 
   check_model(model)
 
-  fct_color <- NULL
-  color     <- NULL
-  obs       <- NULL
-  dsr       <- NULL
-  txt       <- NULL
+  if (is.null(threshold)) {
+    threshold <- 3
+  }
 
-  g           <- ols_prep_srplot_data(model)
+  g           <- ols_prep_srplot_data(model, threshold)
   d           <- g$dsr
   d$txt       <- ifelse(d$color == "outlier", d$obs, NA)
-  f           <- d[color == "outlier", c("obs", "dsr")] 
+  f           <- d[d$color == "outlier", c("obs", "dsr")]
   colnames(f) <- c("observation", "stud_resid")
 
   p <-
     ggplot(d, aes(x = obs, y = dsr, label = txt)) +
     geom_bar(width = 0.5, stat = "identity", aes(fill = fct_color)) +
-    scale_fill_manual(values = c("blue", "red")) + xlab("Observation") +
-    ylab("Deleted Studentized Residuals") + labs(fill = "Observation") +
-    ggtitle("Studentized Residuals Plot") + ylim(g$cminx, g$cmaxx) +
-    geom_hline(yintercept = c(0, g$nseq, g$pseq)) +
-    geom_hline(yintercept = c(-3, 3), color = "red") +
     geom_text(hjust = -0.2, nudge_x = 0.05, size = 2, na.rm = TRUE) +
-    annotate(
-      "text", x = Inf, y = Inf, hjust = 1.2, vjust = 2,
-      family = "serif", fontface = "italic", colour = "darkred",
-      label = paste0("Threshold: abs(", 3, ")")
-    )
+    geom_hline(yintercept = c(0, g$nseq, g$pseq)) +
+    geom_hline(yintercept = c(-threshold, threshold), color = "red")
+
+  p <-
+    p +
+    annotate("text", x = Inf, y = Inf, hjust = 1.2, vjust = 2,
+             family = "serif", fontface = "italic", colour = "darkred",
+             label = paste0("Threshold: abs(", threshold, ")"))
+
+  p <-
+    p +
+    scale_fill_manual(values = c("blue", "red"))
+
+  p <-
+    p +
+    labs(fill = "Observation") +
+    xlab("Observation") +
+    ylab("Deleted Studentized Residuals") +
+    ggtitle("Studentized Residuals Plot") +
+    ylim(g$cminx, g$cmaxx)
+
 
   if (print_plot) {
     suppressWarnings(print(p))
   } else {
-    return(
-      list(plot = p,
-           outliers = f,
-           threshold = 3)
-      )
+    return(list(plot = p, outliers = f, threshold = threshold))
   }
 
 }
-
-#' @export
-#' @rdname ols_plot_resid_stud
-#' @usage NULL
-#'
-ols_srsd_plot <- function(model) {
-  .Deprecated("ols_plot_resid_stud()")
-}
